'''
logo.py: Embedded icon for use in the "About" panel

The rest of this file was generated by using the img2py.py program that
is provided with wxPython 4.0, with the following commands:

  inkscape -o eprints2archives-icon.png  -w 160  ../.graphics/eprints2archives-icon.svg
  img2py -f -i -n Logo eprints2archives-icon.png logo.py
  rm eprints2archives-icon.png

The only changes to the output were to add the file header and this
explanatory comment.

Authors
-------

Michael Hucka <mhucka@caltech.edu> -- Caltech Library

Copyright
---------

Copyright (c) 2020 by the California Institute of Technology.  This code is
open-source software released under a 3-clause BSD license.  Please see the
file "LICENSE" for more information.
'''

#----------------------------------------------------------------------
# This file was generated by /usr/local/bin/img2py
#
from wx.lib.embeddedimage import PyEmbeddedImage

Logo = PyEmbeddedImage(
    b'iVBORw0KGgoAAAANSUhEUgAAAKAAAADJCAYAAACkNDm/AAAACXBIWXMAABqKAAAaigFGPbT9'
    b'AAAAGXRFWHRTb2Z0d2FyZQB3d3cuaW5rc2NhcGUub3Jnm+48GgAAHGtJREFUeJztnXl8VOW5'
    b'x7/PORMSkDVIZUkmQahawWqLqF1cWFSsV2u12GrVWr1FBSaBLtZumrbXi6W1YTKASovaxRVb'
    b'e6sFLSpXtFw3atVaRRGYmbCJgCwKJDPnuX9MQJZMcs7MnDkzk/P9fPL5wORdfjP5zTnved/n'
    b'fV7BxxP0W4OrscxRqHwKi6MRqoEgcFjbTwDY1vazE2UtIq8DbyDJ1+jXvFwaSHj3DnKDeC2g'
    b'q6ATMRkYHIPoBWCcCXpUlk1uB30SlcdRfURmx9flRGie8Q3oMjo9eCQJnYzIpcAgl7pJoCwE'
    b'mceG6GOygKRL/eQc34AuodNqT0CTP0bli4CZx67XIPJf9Iv+thhu0b4Bc4xOq63F0hmgFwOG'
    b'd0rkLbBuoin+gIB6p6NjfAPmCG0gwJbgFOC/gJ5e69mPpZjW1dLYvNJrIe3hGzAHaKh6GGLc'
    b'A3qy11rSsBPR7xGO31ZoV0PfgFmi9cGJKL8BenutpXPkfna3Xi3z1n3otZK9+AbMEAUhFLwe'
    b'4b/xdKznFH0Fy/iSzI6u9loJ+AbMCJ2IyaDgfODrXmvJkA2YjJfG2OteC/EN6BCdNKqMik33'
    b'ABNz0Nwe4EVgGfAv1HibgPUuRmI7HwaSGGZvzEQvLKMaYSSixwHjgMFZ9yy8S9IaL7ObX8u6'
    b'raxk+NhGQair/gPIpVk0k0T5K6L3kdj9qMzdtNOxjtDQ4zGSF6L8J9mZ8T0sa6yXJvQN6ACt'
    b'q7kV9FsZVt+NcDtihGXWmjU50dNAgK01XwS9CeW4DFuJkTBPlrlrNuRCk1N8A9pE62uuRvU3'
    b'GVUWuY+E8X2ZszqaY1kAaAMGW4OXodxCRst98jxmcow0Nu/KubjOes53h8WI1lePRmUpUOGw'
    b'6jqEayQce9QNXQej06sqSUokwyHC76UpdkXORXWCb8BO0MkDehLo/k9gmLOa8jQtgYvl9nfe'
    b'dUVYB2h98AqUeUC5w5qXSFP8fldEpaGkDKgNBNg+eBB7pDum2QtDPsRo3UnvdeszXZjX+uDt'
    b'KNc4rDWfyvi1XgYDaF3NZxF9GOVjDqptxbSOk8bmta4JO4iiNqBOrT0GU8ejehrI8aBDgbJ2'
    b'iiaAKMpLwHNYyYUyZ+1bnbYfqjodMZbg6HPSX9IUv74Qlrw0FDwW4SngCNuVRBdJOP4F91Qd'
    b'1F2+OsoVOq22L6pXo9blKdNlzBuo3EVr4Lft3SZTT5jBfzh7utQ50hSfmoWmnKPTgyNIyhLQ'
    b'AbYrCefla9xaNAbU6VWVJOQHiEwCeuWw6V3AbzBkhsyKrt/XX331ZFTmOFD4MJXxL0sDVg61'
    b'5QQNVZ+KyBNAN5tV3qQydlw+hhAFb8DUmmv1tYj8DOjvYlc7QH7K+mgjh9WW0dtaCQyxWXcF'
    b'Fd1Hy8wVO1zUlxVaH/xm24OJTWSqNEUdfAEzo6ANqNOrhpA07gLOzF+n/B8Gz6J812aNFsQa'
    b'LeHmV13VlQO0LvggdpcQlTh7BgyTectb3dRUsFEcGqo9haSxnHyaD0D4jAPzgXJzMZgPgLLE'
    b'ZMDeiodQTff3crHe3SEFaUAN1VyIWEtw8vTmCfIW/Xvd4rUKu8it695DnHy5Ml52tE3BGVDr'
    b'gxMRvR/nqw75R/m+NLze4rUMR/SL3YvyD5ulR2mo9hQ35RSUATUUHI9yD+3P5RUWwksSif7J'
    b'axlOkQYsDG6wXcGwvuKinMIxoE6tPQZhAdmZrwXkVUQXAQtQHkd4Dcj9QFr11py3mSckHFsM'
    b'/NNWYWWiNrjnk4BbDTtBr6ytwLQeROmbQfUPQe9D5AGsbkslsnJPu+33SpyMyESQr5L9dM5a'
    b'KuMPZdmGt6iGEbnLRskhbK3+PMSXuiGjIAxIb+uWDOLZWhHmEEjcLLeue6+jgnL3mt3A08DT'
    b'OnnADZg9rsPQH6L0yUivcG8xbPrukB3m/fS2wtjZTGUZZwOuGNDzW7BOq/k04HT56k3gMxKO'
    b'Te/MfAcjczftlEj0FyT1WGChw37bGjHuzaheAdH2pXzEXmE91S0dnhpQQbA0grPUFYvZHThF'
    b'mmLLs+lbZsfXURk7D+HnDquulVlr7I2fCh1D7Q4jTtIra12ZlfD2ClgfPBf4rIMai9lunC/z'
    b'Vm3LRffSgCXh2A2gP3NQ7Ylc9F0QdOvxJNhKZFROH+tENyR4a0Dlxw5K/4uK7he13TpyijTF'
    b'b0T5nb3CYu+2VQTIzBU7UF6xVdhihBsaPDNg2wTnSTaL7yKZvMjVxf7krimphD4d8g7b5K+u'
    b'afAC4e/2yulwN7r37goo1tUOCt9oJ4A0G2Tupp2IcT6Q7qFmK2pd6sYV2FNU37BXzigdA2rD'
    b'iG6I7Y3dq6js2eSqoDYkvHoFlh4PchfC3nHmduAeTOskiTS/kA8deeYdW6UMdbgnxh7ezANu'
    b'3nEaYnsO7uf5XG9tS3V7FXCVXn90L2au2FkI4fWuEdBVJG1E5SmVbnTvzS1YxN6eA2EbuxN/'
    b'cFlN+u5nrthR0uZLscVWKXEn56E3BlS1F2Gh/LmQUomVJH362EsNohzmRveuRURrw4hubHq/'
    b'FtPshdIPkSQG25DkdpLGq0D3ztXJlyUc/aNbGn1SaF2wBTtBIKbVI9fZE3JmQJ1aPRjhLIQz'
    b'QUaR2sid3RgzYQzyKmdJV6Et25fNMbbcj7KYQPLxXO0dzsqA2jCiG1t2XAB8ExhLbm/pG6Up'
    b'NjCH7fm0g4YGDkC6Oc3eYAFLUJ1P//iCbAIzMjJgKiF39eUgNwK1mXbecSf8n0RiTpbp8o5O'
    b'GtyDHmXH05rY7PY8pVvolCFHYZorsmhiNXAL62PzMzmfxPEVS0NVJ7El+DLInbhlPgDD5tOZ'
    b'R+i02jOoCLyNpcswzRVaX/1Hvf7oXO5Xzg8B6ZdlC0OBOxgUfDGT8H3bBtQGAloXnIEYy4CR'
    b'TjtyjFKwT79aVzUBy1rI/skhVS5kz66ndHqVK/NlrqFGrqZXPoVYz2h98CfaYH/sb8uAOmVI'
    b'f7YEFwE3kK9Tf7TwMgwA6NSac8B4mPae4pUTSRiLdcoQNzfQ5xZDcvlFD6DcyJbgIp1Wayu6'
    b'vVMDamhIFWZgGTA+a3lOEP0gr/3ZQEM152Low3S0Y0/4NKb5hH578OH5U5YF78vLwNYctzoe'
    b'y1qm06s6zSzRoQG1/sggYv5vDk52dI4ab+a9zw7QUPDLiD6MvZx7J9AaeFon1xb8U7zcvWY3'
    b'KjNcaPoTJI0lOrW6wxzWaQ2YykKVeAzHiRlzwgeQuM+DfttF64IXI9yHsx17xxKwOv0DFAT9'
    b'o7eCzHWh5Y9jyOMaGp5230m70zBt554tIvvbbhRYyUfrjX2Aj5N6ckqHhfANCcfsBYi6jIaq'
    b'L0Hkd2Q+qb4C0xqXz6SPmZLKhyhXgAwndWh2f1IJmrLdp72Qyth57WUOa9+A9cGfoNyYYWfP'
    b'gN6FBBZKePXGdtufXDsQU78A1uWIfJ59f1x9BeF7Eo4/nmHfOUVDNVch+muyn2BfjWGMzVV2'
    b'/HyiDSO68d72T2JwNsjlwNEZNSR8X8KxQ9KYHGJAra86GTWexfk3/lnU+K5E1jznpJJOq+2L'
    b'ZQ1DkxslsrbZYZ+u0ZbO7HZyt7oTxWSsNMZW5ai9vJNKlVfzhdTxZPpJh9VbMeQUmRU9IC3I'
    b'AQbUiZgMDr7scI/uHpTricQipRK6pKHgNQhzyXm0kMZQxkokbi8ItEBpWwn7HshNOLs9v0Bl'
    b'7DP734oP/IAHBa92aL4tCOMlEmsqHfNVX4dwG66EqkkQZInWVX08923nD2kgIU3xm4FzcDaF'
    b'cxKba648oK29/9Arayvoba0G7E4dvA+Mz3Z/biGhdTXfAf1FHrraiMm4QjgsMFu0LjiK1FZV'
    b'u2lV1rB7wFF7E19+9C3vrZdh33xJVL9SUuYLBb+XJ/MBHIHFUzq1KsPjtQqHlAfkQrAdEVNL'
    b'+btf2/sfA9oGl+h0B/3+TCLxvzkoX9BoXbABIb+JJpWPYZhPan2V08F8wSFN0SUoP7JdwZAp'
    b'+/4JQKhqNHCsvd54jd0D/tuZxMJFQzU3Azd1UORNRE9nfSyABGqAzvaoJBC+j2n1p9uengiT'
    b'gDRh7zoANZ5qy49T3GyI/RKwt2tQOVFDQ4+HvQYU034SQrWudztxdb7Q+uBMRH/QQYlX0JbT'
    b'JBxfKgtISnhVjMrY1+kwU5TOkHDsFmls3iK/3PiBhGO/Bjl7v22eB9MfS5/Q+urR2bwXr5EF'
    b'JBG+bbuCkbwE9o0B9UKb1ZZLU/NjTsUVGgqi9cHGTpKRL8fUsRLZsGn/F6UBC9X056lJ4J5D'
    b'XmqKLsOyziL9E2M/kMU6reYzdvQXKhKOPYvd3DnKuQCG1h8ZxHZgqbp+boTbKAj1wVko0zoo'
    b'thzTOksam9MFxb7fQd12fyeR5hdQGUe6zAtKHyxdrHU1YzpouwjQ2TYLjtTpVUMMrKTd3G8t'
    b'tMqfM5VVCLSdeB5BqUtbSPg72m1sB+bLGIlEX0Y5nfRHJRwG+qjWBcfluu+8sftjC7E7N5gw'
    b'TzbA+pTNppfKbbFcx43lDW3AoK5mPnz0BNYOz1Le/RyJrNzulg6JxP6NZYwB1qUp0gP4i9YH'
    b'83s+So5IPR+IvbV80dEGiN1ZeXtZlAoQnYjJluCdoN/ooNhSErvOycdxWzJ7zZuIORZIFyHT'
    b'A+URra8+320triDWM/bK6VEGgr2sRyKvZaPJK3QiJoOCdwNfT1+IxzGtCTJ3k70sATlAwqtX'
    b'gDUGSBeAUY7KAp1WfUG+NOUMMV62Vc6SWgO7GeMtii6KQxsIMKj6d8BlaQuJLmKHcUGud/zb'
    b'QZqa3yZpfh7SfrbdsORBDdXYnaUoDHYH7AVbCIMNsJl0xjIKepvkwaQ2zVc/CHJp2kLCX7HK'
    b'v+Rlzj+ZszqKBMaQPk1aGaIPan0w/Zeo0Bj4znvYC07paWAnRwtAgKJJzNiWseFBkC91UOwh'
    b'dg34UnvniuQbCa+KEUiMAd5OU8REuVvrg1fkU1emtIVb2fFLDwO7pwiZe+weduwpGhpezpYd'
    b'DwFfTF+IB6iMXVJIKzryq3VxEsZpKOkiZEyUO7WuuqMHqULCTpxgq0HadcqDaDEyOcUor+ik'
    b'wT2QlkeB89IWErmP/rHLCvGgGZm7ZgOtZWPbjhdrDxNkvtZXT86rMIfopME9sBdRv9OAtGuU'
    b'ByJGbRaaXEe/c8RhdA88QocbqXQ+/aIFab69yO3vvIvVMg4k3RnEgspsrQuG8irMCT3KamyW'
    b'3G6QSi5jB3vRMh6g3zniMPZ0exRlbPpC/JrK+KT2dmYVGhLZsIlWPQN4MV0RIKyhYEfLid5h'
    b'cYytcqpRg/QD34MpyExVOr2qO3vKFyNyRtpCQhOR2DXFYL69yG2xrbRyNh2ZUGjUUDD9sqJn'
    b'WPa8IrLSQMReWLgwxq3jmrIiaVyPkD6KRPVWCcfqi3HPitwW28ruwJmg6XcaCr/S6VWuHKGQ'
    b'OcZZ9srpGwYiz9pstRd9kxMy1uQen+/gdzMkEv9O3pS4gMxbtY2KHmcB6f5OJpbh6qnmTtAp'
    b'Q46yvWVT9O8Gfde8SsfhRR9hyXVZaHOLlWle/4k0xToINi0eZOaKHSR2nYPq/7ZbQKVwVqnM'
    b'wLU2S37AriP+YUgDFiKLbFY6s+DCxyUwgwMjS5IoN0hTrMEjRa4gczftZE/yXISDjgqT+6Up'
    b'uswbVQeiU4b0R/Qqe4V5UuYtb03N1aj1AMglNqoJls4k36naOkDCq2I6ZcgnMYyLQXpjWIuk'
    b'qTndFEZRI/PWfahwHvXBc7HkBITXqYz+j9e69mEGfoCqzQOI5EFo2xesoeHlSMta7AYmqH5D'
    b'IvG7MxJZArQlLGr/0GoxB6bLiVPKtO0Pfg57E9AfUtF9oMxcscMAkMjKPajcYbs3kSYNBQt2'
    b'XtAnv7SlX/sDtvMJyd174y4/2phuMhuweyZbL4S/FEXuOx9XSR082XIf2Jx8Bgsz2bj3P/sM'
    b'KLOi69sS8thlGIY8qVOG2l128Skx9MraCjbvfACwd/ZfinuksXnfzMWBCXgM62fYPbwuxTGY'
    b'yed1ak36JTCfkkS/Nbia3skliDqJ2P6QQOKH+79wgAGlsXkLwg0OtRyBoU9oXfAOrR96hMO6'
    b'PkWGTsTUuuAkEoFXQRxOgMst8qt18f1fOSQFWWonP4841CXAJDT5jtYHb9f6qpO1wcPT2H1y'
    b'jk6r7auh6usYFHwNuAP72bDakOepjB6SDL39pxYxv4kmXwKqHOo8DOUaMK5hS80mrWM58Abo'
    b'NrR4Iqrbx3pOIs1PO6mhoaqTMIziHCOrmij9gGGIcSKW9VlEMs0VvZ1k4or2wuDaNaCEV2/U'
    b'abXnYVnPYHfPyCHoAGBC24+LB8PmC2MG4MiAiDEV5XJ39LiN7J89MpuGkghfS3eWXtrbpMxa'
    b'80+QrwCe75nwKVoU0ToJxx5NV6DDcZo0RReCdQGQ9y2LPkWPokyTcLzDqb1OHxSkqfkxRCeA'
    b'bOqsrI9PG3sQrpRIrKmzgraeVCUcX4qYJwIlk5LXxzXWItbpdg8asj1V0pac8RSUG/DHhT7t'
    b's4CyxAkSbn7ebgVHc3XSQEIisZ9jGScg+ieKMMzdxwWE18A6R5piF8ut69rPf5iGjCaLZfaa'
    b'NyUcvwgYTSoKosjn+Hwy5AVUL6Vf7IRMM+dmegAfsDdFP5frdcE6ypiI6Nkg41BsBiX6FB3C'
    b'a6g+jgb+IJHVr2TbXFYG3KcplbhyHjBPGwiwaciRmIERCEdiUQlWb0SKIrVHeiTd9sj0KK8j'
    b'NnMmFxpKEmE7sBlYjcrrqPWyzI6nS6yZEUW/PuEFfkR07vADBnw8xTegj6f4BvTxFN+APp7i'
    b'G9DHU3wD+niKb0AfT/EN6OMpvgF9PMU3oI+n+Ab08RTfgD6e4hvQx1N8A/p4im9AH0/xDejj'
    b'Kb4BfTzFN6CPp/gG9PEU34A+nuIb0MdTfAP6eIpvQB9P8Q3o4ym+AX08xTdgJogRTfObD+i3'
    b'enNetRQ5vgEzoTL6AsJLh7yuent7meB90uPnhskQnV5ViWXchHIq8AHow6yPh2UBSa+1+fj4'
    b'+Pj4+Pj4+Pj4+KTBfwp2iE4aVcZhG2tImtVYVGBqT6A7sIuk7CQguxArRnMs6j8Rd45vwA7Q'
    b'BgzerzmBpJ6G6GkgxwNB7OXWbgHeAV5AeArDelIam9e6KrgI8Q3YDhoaejySuAyVSxEG7/8r'
    b'nH1mB5d/BuE3GNYCaWz2z9/DN+ABaF1wHMiPQU9PvYAirnxGW4CfUtnrNml4vcWF9osG34CA'
    b'1lWPBJkLnJqfDvcZexUwSZpiT+al3wKkSxtQQ8PLMfb8KHX+neTkzBSnElI/MoPKaENXXEfu'
    b'sgbU6VVDSBp/Ak7C+dguh0LaroaiizD0oq42NuySBtRQ7SlgPYww0GstB7GExK7zZe6mnV4L'
    b'yRddLhxLQ9WnItYTBWg+gDGY3R/SiZheC8kXXcqAOjX4OUQWAT281pIW4WwGB2d4LSNfdJlb'
    b'sNYPPRpNvgD0orDfd+oMZkMvlFnxP3usxXUK+Q+RM3TSkX2oSDwPHJ3Pbsn08009mGxAux0j'
    b'kZXbcyursPBi6iH/lCfvJjvzfWSmVCj+k6Avg67BkvcIiJKgAhgMHIvoGSATSK0ROzdiao5w'
    b'EOy5GQhlobvgKfkrYIdHq9pnF8IdqDVXmprfttXvtNq+JK1rEH4A9HbcY+oqaGFax0hj80rH'
    b'9YuEkjagfnvw4bSa/wY5HOfvte3KpQ9jaijTQAKdWj0Yw7h33/Ke8xbulKb41ZnVLXxK+yk4'
    b'UfZTkAFkYj4lAXqdNMUvzCaKRWbH17H78DOBP2ZQXYErdMrQmkz7L3RK1oA6ZWgNlv4ne58q'
    b'HVQFdoP+hzTFb8+FFpm3vJXdAy4BnnVaFSSAmfCvgEWHkfwhQhlOrn6qCppE9QKJxP+WSzky'
    b'b3krpvVVVHfi7EuhIFdoQ2n+rUryTemUIf0Rvg7q7OonIohxba7Nt6/5xua1YPwUZ0MCAWrY'
    b'UpPhGLKwKUkDYpqXAd1AHI799F4JR+e7omkv/XuGgTedV7QuyrmWAqA0DYhc5bCComzGVNfn'
    b'3KTh9RaEmx1W07Z5xZKj5Ayo9UOPBv2kw2qC6I+ksXmLK6IOxuq2AHgP+2NBAYbp9Krh7ony'
    b'hpIzIFbyHIc1FFhLZe873ZDTHhJZuQdhPk6nh5Iy3h1F3lF6BhScGlAQZud9b4bF7zKodWLO'
    b'dXhMSRlQGwignOasEklEfuuSpLRIJPZvoDk19WO71ijXBHlESRmQrVXHIlQ4qiPyrMyKrndJ'
    b'USd98wTi6El9hF5Z6+z9FTilZUA1js+g0sLcC7GLLHZYoYxeks+QMtcpMQNqBgaUF3MvxCaW'
    b'/tNxHbGOdEGJZ5SWAQ2GOq6TTLzqghJ79O+1EpxuxbScv8cCprQCUtUY4mCZVYGtmGat1gVr'
    b'3RPVAVt2ALyLMshBBoaSugKWlgHRKgeFBaiEdpKN5xtH2Wak2jUdHlBat2D4mNcCXMegv9cS'
    b'cknJGFAnjSoDyrzW4TKKcrjXInJJyRiQvjtLan4sDQL+FbAwSe4o91pCnujrtYBcUjoGbLFK'
    b'eoPVfgRKKXVH6Riwe5/dXkvIGwOHl8zsRekYsMeKrpPWLLmtZB62SsaAbckdu0a62/Lybl5L'
    b'yBUlY8A21uN8G2bxYZWVzBWwZMYSbawFHGzilu9KU/SXrqnx6ZRSuwI2Oyx/rCsqfGxTWgYU'
    b'fcthjZKLMC42SsuAlvGyswo6Uq8dVvrrxwVMaRkw4DjA06C8tST32xYLpWXAxthq0E2ogydh'
    b'5WsuKvLphJIyoKSmYBY7PF5rnE6tKako42KipAwIgOJ0o4+JWN9yRYtPp5SeAZPmY+DonF5F'
    b'5Js6rbbWJUU+HVByBpS5azY43O4oQDmW9Qu3NPmkp+QMCIDw+wxqfVnrg1fkXItPh5SmAXe1'
    b'/hllM04zkarOKcUMVIVMSRpQ5q37EGQWjjORSk+Sxr06vaq7W9p8DqQkDQiAKbOBHTiPjhlN'
    b'0nhIG0YUTMhTqeaHhhI2oMxa8z4qM8nsLJQvsHn74/rtwZ7uQNPpVZVaF7yercHnvdThJiW9'
    b'j0JDw8uh5V8ImY3rlGZgskRij+RWWQddNmCwufpzIJcjXAZ0R3hXwrEj8qUhn5S0AQG0rmoC'
    b'GIvI7lT0v2HJz2V29KkcStuHTqsZhDIGS88AnYDsy36Q0uwbsLjR+pq5qF6XfUOsxOCPJOVv'
    b'9Kh4UWau2OGo+qRRZVRsrMUyh2MyDNXjgNM58CDFQ78ovgGLG72ytoLeyedAMkjfdmBTfPSZ'
    b'JYFVQBShGZUPEd1ryL4oFaQOxu4DVADVQBAO2VLZ+ZXZN2Dxo1OGHIVhLkNymlnAyW098yFA'
    b'CRuwZJ+CD0bmrH0L1QmkpmZy1qxLZbsMXcaAADI7/hJqnQd84LUWnxRdyoAAEml+GjU/hxL1'
    b'WotPFzQggERWvwIto0Gebnup9PcSFyhd0oAAEtmwicroWJCpwE7At6EHdFkDAkgDljRF52Ba'
    b'nwC5H8Fq+5VvxTzRpQ24F2lsXitN0UswZCTwe7QgjKjAMmAahvVpD3W4ij810A46ZWgNgcTX'
    b'ULkEGOleRxz8F0iAvoQYD4G5QMKrYq71XSD4BuwEraseiXA+yGdRPkf6DKXtTTR3Nvm8C9Xn'
    b'MWQplv6d5O5lMnfTzlzoLhZ8AzpAQQgFP4EwEmUoBkNRhpLK29wXKAd6khra7CI137gVZCeq'
    b'2xBZiVorMWQlSVnJxmhMFjjaQOXj45NL/h+HkDwWxxeFugAAAABJRU5ErkJggg==')
getLogoData = Logo.GetData
getLogoImage = Logo.GetImage
getLogoBitmap = Logo.GetBitmap
getLogoIcon = Logo.GetIcon

